/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012, 2013  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.framework;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.image.BufferedImage;
import java.awt.image.BufferedImageOp;



/**
 * This class contains various bitmap operations used by some gfx tests.
 * 
 * @author Pavel Tisnovsky
 */
public class CommonBitmapOperations
{
    /**
     * Width of tested buffered image.
     */
    public final static int DEFAULT_TEST_IMAGE_WIDTH = 256;

    /**
     * Height of tested buffered image.
     */
    public final static int DEFAULT_TEST_IMAGE_HEIGHT = 256;

    /**
     * Grid size for images with checker pattern.
     */
    private static final int GRID_SIZE = 20;

    /**
     * Create new buffered image and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param bgcolor
     *            background color
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType, Color bgcolor)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, bgcolor) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param bgcolor
     *            background color
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType,
                    Color bgcolor, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, bgcolor, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param horizontalFlip
     *            enables performing horizontal flip of image
     * @param verticalFlip
     *            enables performing vertical flip of image
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType,
                    boolean horizontalFlip, boolean verticalFlip)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, horizontalFlip, verticalFlip) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param bgcolor
     *            background color
     * @param horizontalFlip
     *            enables performing horizontal flip of image
     * @param verticalFlip
     *            enables performing vertical flip of image
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType, Color bgcolor,
                    boolean horizontalFlip, boolean verticalFlip)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, bgcolor, horizontalFlip, verticalFlip) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param cropRegion
     *            region in the image to crop
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType,
                    Rectangle cropRegion)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling and cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, cropRegion) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param bgcolor
     *            background color
     * @param cropRegion
     *            region in the image to crop
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType,
                    Color bgcolor, Rectangle cropRegion)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling and cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, bgcolor, cropRegion) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithEmptyImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = BitBltOperations.createBufferedBitmap(imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing checker pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithCheckerImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param bgcolor
     *            background color
     */
    public static TestResult doBitBltTestWithCheckerImage(TestImage image, Graphics2D graphics2d, int imageType, Color bgcolor)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = ImageFactory.createCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, bgcolor) ? TestResult.PASSED : TestResult.FAILED;
    }
    
    /**
     * Create new buffered image containing checker pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithCheckerImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing checker pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param horizontalFlip
     *            enables performing horizontal flip of image
     * @param verticalFlip
     *            enables performing vertical flip of image
     */
    public static TestResult doBitBltTestWithCheckerImage(TestImage image, Graphics2D graphics2d, int imageType,
                    boolean horizontalFlip, boolean verticalFlip)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, horizontalFlip, verticalFlip) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing checker pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param cropRegion
     *            region in the image to crop
     */
    public static TestResult doBitBltTestWithCheckerImage(TestImage image, Graphics2D graphics2d, int imageType,
                    Rectangle cropRegion)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling and cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, cropRegion) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing checker pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithCheckerImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal checker pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithDiagonalCheckerImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal checker pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image and then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param bgcolor
     *            background color
     */
    public static TestResult doBitBltTestWithDiagonalCheckerImage(TestImage image, Graphics2D graphics2d, int imageType, Color bgcolor)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = ImageFactory.createDiagonalCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, bgcolor) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal checker pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithDiagonalCheckerImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal checker pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal checker pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param horizontalFlip
     *            enables performing horizontal flip of image
     * @param verticalFlip
     *            enables performing vertical flip of image
     */
    public static TestResult doBitBltTestWithDiagonalCheckerImage(TestImage image, Graphics2D graphics2d, int imageType,
                    boolean horizontalFlip, boolean verticalFlip)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal checker pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, horizontalFlip, verticalFlip) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal checker pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param cropRegion
     *            region in the image to crop
     */
    public static TestResult doBitBltTestWithDiagonalCheckerImage(TestImage image, Graphics2D graphics2d, int imageType,
                    Rectangle cropRegion)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal checker pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling and cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, cropRegion) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal checker pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithDiagonalCheckerImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalCheckerImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing grid pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithGridImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains grid pattern
        BufferedImage bufferedImage = ImageFactory.createGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing grid pattern and then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param bgcolor
     *            background color
     */
    public static TestResult doBitBltTestWithGridImage(TestImage image, Graphics2D graphics2d, int imageType, Color bgcolor)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = ImageFactory.createGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, bgcolor) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing grid pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithGridImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains grid pattern
        BufferedImage bufferedImage = ImageFactory.createGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing grid pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param horizontalFlip
     *            enables performing horizontal flip of image
     * @param verticalFlip
     *            enables performing vertical flip of image
     */
    public static TestResult doBitBltTestWithGridImage(TestImage image, Graphics2D graphics2d, int imageType,
                    boolean horizontalFlip, boolean verticalFlip)
    {
        // create new buffered bitmap with given type
        // bitmap should contains grid pattern
        BufferedImage bufferedImage = ImageFactory.createGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, horizontalFlip, verticalFlip) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing grid pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param cropRegion
     *            region in the image to crop
     */
    public static TestResult doBitBltTestWithGridImage(TestImage image, Graphics2D graphics2d, int imageType,
                    Rectangle cropRegion)
    {
        // create new buffered bitmap with given type
        // bitmap should contains grid pattern
        BufferedImage bufferedImage = ImageFactory.createGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling and cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, cropRegion) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing grid pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithGridImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal grid pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithDiagonalGridImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal grid pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal grid pattern and then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param bgcolor
     *            background color
     */
    public static TestResult doBitBltTestWithDiagonalGridImage(TestImage image, Graphics2D graphics2d, int imageType, Color bgcolor)
    {
        // create new buffered bitmap with given type
        // bitmap should be empty - solid color pixels
        BufferedImage bufferedImage = ImageFactory.createDiagonalGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, bgcolor) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal grid pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithDiagonalGridImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal grid pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal grid pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param horizontalFlip
     *            enables performing horizontal flip of image
     * @param verticalFlip
     *            enables performing vertical flip of image
     */
    public static TestResult doBitBltTestWithDiagonalGridImage(TestImage image, Graphics2D graphics2d, int imageType,
                    boolean horizontalFlip, boolean verticalFlip)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal grid pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, horizontalFlip, verticalFlip) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal grid pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param cropRegion
     *            region in the image to crop
     */
    public static TestResult doBitBltTestWithDiagonalGridImage(TestImage image, Graphics2D graphics2d, int imageType,
                    Rectangle cropRegion)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal grid pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling and cropping
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, cropRegion) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing grid pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithDiagonalGridImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalGridImage(GRID_SIZE, DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white horizontal stripes then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalStripesImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains horizontal stripes
        BufferedImage bufferedImage = ImageFactory.createHorizontalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white horizontal stripes then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalStripesImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains horizontal stripes
        BufferedImage bufferedImage = ImageFactory.createHorizontalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white horizontal stripes
     * then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithHorizontalStripesImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createHorizontalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white vertical stripes then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalStripesImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains vertical stripes
        BufferedImage bufferedImage = ImageFactory.createVerticalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white vertical stripes then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalStripesImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains vertical stripes
        BufferedImage bufferedImage = ImageFactory.createVerticalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white vertical stripes
     * then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithVerticalStripesImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createVerticalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white diagonal stripes then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithDiagonalStripesImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal stripes
        BufferedImage bufferedImage = ImageFactory.createDiagonalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white diagonal stripes then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithDiagonalStripesImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal stripes
        BufferedImage bufferedImage = ImageFactory.createDiagonalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white diagonal stripes
     * then perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithDiagonalStripesImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains horizontal color stripes
        BufferedImage bufferedImage = ImageFactory.createHorizontalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains horizontal color stripes
        BufferedImage bufferedImage = ImageFactory.createHorizontalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithHorizontalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createHorizontalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains vertical color stripes
        BufferedImage bufferedImage = ImageFactory.createVerticalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains vertical color stripes
        BufferedImage bufferedImage = ImageFactory.createVerticalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithVerticalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createVerticalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithDiagonalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal color stripes
        BufferedImage bufferedImage = ImageFactory.createDiagonalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithDiagonalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains diagonal color stripes
        BufferedImage bufferedImage = ImageFactory.createDiagonalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing diagonal color stripes and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithDiagonalColorStripesImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createDiagonalColorStripesImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white dot pattern and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithBWDotsImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains simple black and white dot pattern
        BufferedImage bufferedImage = ImageFactory.createBWDotsPatternImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white dot pattern and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithBWDotsImage(TestImage image, Graphics2D graphics2d, int imageType, int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains simple black and white dot pattern
        BufferedImage bufferedImage = ImageFactory.createBWDotsPatternImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing black and white dot pattern and then
     * perform basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithBWDotsImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createBWDotsPatternImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing color dot pattern and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithColorDotsImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        // bitmap should contains simple color dot pattern
        BufferedImage bufferedImage = ImageFactory.createColorDotsPatternImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing color dot pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithColorDotsImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        // bitmap should contains simple color dot pattern
        BufferedImage bufferedImage = ImageFactory.createColorDotsPatternImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing color dot pattern and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param rop
     *            selected raster operation
     */
    public static TestResult doBitBltTestWithColorDotsImage(TestImage image, Graphics2D graphics2d, int imageType, BufferedImageOp rop)
    {
        // create new buffered bitmap with given type
        // bitmap should contains checker pattern
        BufferedImage bufferedImage = ImageFactory.createColorDotsPatternImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling, no flipping and no cropping and using RescaleOp
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, rop) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal grayscale gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalGrayscaleGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalGrayscaleGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal grayscale gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalGrayscaleGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalGrayscaleGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical grayscale gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalGrayscaleGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalGrayscaleGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical grayscale gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalGrayscaleGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalGrayscaleGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal red gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalRedGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalRedGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal red gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalRedGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalRedGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical red gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalRedGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalRedGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical red gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalRedGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalRedGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal blue gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalBlueGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalBlueGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal blue gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalBlueGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalBlueGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical blue gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalBlueGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalBlueGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical blue gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalBlueGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalBlueGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal green gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalGreenGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalGreenGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal green gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalGreenGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalGreenGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical green gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalGreenGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalGreenGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical green gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalGreenGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalGreenGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal yellow gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalYellowGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalYellowGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal yellow gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalYellowGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalYellowGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical yellow gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalYellowGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalYellowGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical yellow gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalYellowGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalYellowGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal magenta gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalMagentaGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalMagentaGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal magenta gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalMagentaGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalMagentaGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical magenta gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalMagentaGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalMagentaGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical magenta gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalMagentaGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalMagentaGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal cyan gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithHorizontalCyanGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalCyanGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing horizontal cyan gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithHorizontalCyanGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createHorizontalCyanGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical cyan gradient and then perform basic BitBlt test.
     *
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithVerticalCyanGradientImage(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalCyanGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with 1:1 scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing vertical cyan gradient and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithVerticalCyanGradientImage(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ImageFactory.createVerticalCyanGradientImage(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);
        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #1 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithRGBTexture1Image(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture1(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #1 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithRGBTexture1Image(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture1(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #2 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithRGBTexture2Image(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture2(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #2 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithRGBTexture2Image(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture2(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #3 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithRGBTexture3Image(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture3(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #3 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithRGBTexture3Image(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture3(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #4 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithRGBTexture4Image(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture4(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #4 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithRGBTexture4Image(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture4(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #5 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithRGBTexture5Image(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture5(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #5 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithRGBTexture5Image(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture5(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #6 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     */
    public static TestResult doBitBltTestWithRGBTexture6Image(TestImage image, Graphics2D graphics2d, int imageType)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture6(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d) ? TestResult.PASSED : TestResult.FAILED;
    }

    /**
     * Create new buffered image containing RGB pattern #6 and then perform
     * basic BitBlt test.
     * 
     * @param image
     *            image to which another image is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param imageType
     *            type of the created image
     * @param width
     *            width of a image after BitBlt operation is performed
     * @param height
     *            height of a image after BitBlt operation is performed
     */
    public static TestResult doBitBltTestWithRGBTexture6Image(TestImage image, Graphics2D graphics2d, int imageType,
                    int width, int height)
    {
        // create new buffered bitmap with given type
        BufferedImage bufferedImage = ProceduralTextureFactory.createRGBTexture6(DEFAULT_TEST_IMAGE_WIDTH, DEFAULT_TEST_IMAGE_HEIGHT, imageType);

        // basic check if buffered image was created
        if (bufferedImage == null)
        {
            return TestResult.FAILED;
        }
        // BitBlt with custom scaling
        return BitBltOperations.performBitBlt(bufferedImage, image, graphics2d, width, height) ? TestResult.PASSED : TestResult.FAILED;
    }

}

