/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.reporter;

import java.io.*;
import java.util.*;
import javax.xml.parsers.*;



import org.w3c.dom.*;
import org.xml.sax.SAXException;

import org.gfxtest.common.ConfigurationException;
import org.gfxtest.framework.Log;

/**
 * Test reporter main class.
 *
 * @author Pavel Tisnovsky
 */
@SuppressWarnings("nls")
public class Reporter
{
    /**
     * Default encoding used for all input/output operations.
     */
    private static final String DEFAULT_ENCODING = "UTF-8";

    /**
     * Instance of logger class.
     */
    private Log log = null;

    /**
     * Configuration of test reporter.
     */
    private ReporterConfiguration configuration = null;

    /**
     * Directory where HTML templates are stored.
     */
    private static final String TEMPLATE_DIR = "templates";

    /**
     * Name of the main HTML template.
     */
    private static final String INPUT_FILE_NAME = "template_test_result.html";

    /**
     * Name of generated HTML file.
     */
    private static final String OUTPUT_FILE_NAME = "index.html";

    /**
     * Names of special tests.
     */
    private static final String[] SPECTESTS = new String[] {"BlankImage", "SpecialCases"};

    /**
     * Names of tested entities.
     */
    private static final String[] ENTITIES = new String[] {
    	"Lines",
    	"Polylines",
    	"Polygons",
    	"Rectangles",
    	"RoundRectangles",
    	"3DRectangles",
    	"Circles",
    	"Ellipses",
    	"Arcs"
    };

    /**
     * Names of rendering styles.
     */
    private static final String[] STYLES = new String[] {
    	"Normal",
    	"Filled",
    	"Dashed",
    	"Scaled",
    	"AA"
    };

    /**
     * Write report writer duration to the log file.
     * 
     * @param t1
     *            time when the test suite has been started
     * @param t2
     *            time when the test suite was completed
     */
    private void printDuration(long t1, long t2)
    {
        this.log.logSet("duration", Long.valueOf(t2-t1)); //$NON-NLS-1$
    }

    /**
     * Do the report.
     *
     * @param args command line arguments
     */
    private void doReport(String[] args)
    {
        BufferedReader input = null;
        BufferedWriter output = null;
        long t1 = System.currentTimeMillis();
        this.log = new Log(this.getClass().getName(), true);
        this.log.logBegin("report"); //$NON-NLS-1$
        try
        {
            this.configuration = new ReporterConfiguration(args, this.log);
            Map<String, TestResult> testResults = readAllTestResults();

            Reader reader = new InputStreamReader(new FileInputStream(new File(TEMPLATE_DIR, INPUT_FILE_NAME)), DEFAULT_ENCODING);
            Writer writer = new OutputStreamWriter(new FileOutputStream(new File(this.configuration.getOutputPath(), OUTPUT_FILE_NAME)), DEFAULT_ENCODING);

            input = new BufferedReader(reader);
            output = new BufferedWriter(writer);
            writeHtmlHeader(input, output);
            writeHeaderForCommonTests(output);
            // loop over all entity types
            for (String entity : ENTITIES)
            {
                writeEntityHeader(output, entity);
                // loop over all graphics styles
                for (String style : STYLES)
                {
                    String testSuiteName = style + entity;
                    TestResult testResult = testResults.get(testSuiteName);
                    writeTestResult(output, testResult, testSuiteName);
                    this.log.logSet(testSuiteName, testResult);
                }
                output.write("</tr>\n");
            }
            output.write("<tr><td colspan='5'>&nbsp;</td>\n");
            // special tests has to be done separately
            for (String entity : SPECTESTS)
            {
                writeEntityHeader(output, entity);
                String testSuiteName = entity;
                TestResult testResult = testResults.get(testSuiteName);
                writeTestResult(output, testResult, testSuiteName);
                output.write("<td colspan='3'>&nbsp;</td></tr>\n");
                this.log.logSet(testSuiteName, testResult);
            }
            writeHtmlFooter(input, output);
        }
        catch (ConfigurationException e)
        {
            e.printStackTrace();
        }
        catch (IOException e)
        {
            e.printStackTrace();
        }
        finally
        {
            closeOutputWriter(output);
            long t2 = System.currentTimeMillis();
            this.log.logEnd("report"); //$NON-NLS-1$
            printDuration(t1, t2);
        }
    }

    /**
     * Try to close output buffered writer.
     *
     * @param output
     */
    private void closeOutputWriter(BufferedWriter output)
    {
        try
        {
            // close output file
            if (output != null)
            {
                output.close();
            }
        }
        catch (IOException e)
        {
            e.printStackTrace();
        }
    }

    /**
     * Write header for each test to a HTML file.
     *
     * @param output
     * @throws IOException
     */
    private void writeHeaderForCommonTests(BufferedWriter output) throws IOException
    {
        output.write("<tr><td class='value'>Entity</td>");
        for (String style : STYLES)
        {
            output.write("<td class='value'>" + style + "</td>");
        }
        output.write("</tr>\n");
    }

    /**
     * Write header for given graphics entity.
     *
     * @param output
     * @param entity
     * @throws IOException
     */
    private void writeEntityHeader(BufferedWriter output, String entity) throws IOException
    {
        output.write("<tr><td class='key'>" + entity +"</td>");
    }

    /**
     * Write result for one test suite or an 'x' character when the test did not run.
     *
     * @param output
     * @param testResult
     * @param testSuiteName
     * @throws IOException
     */
    private void writeTestResult(BufferedWriter output, TestResult testResult, String testSuiteName) throws IOException
    {
        if (testResult == null)
        {
            output.write("<td style='color:red'>&times;</td>");
        }
        else
        {
            output.write(String.format("<td><a href='%s/results.html'>%s</a></td>", testSuiteName, testResult.toString()));
        }
    }

    /**
     * Write HTML header which is read from a HTML template.
     *
     * @param input
     * @param output
     * @throws IOException
     */
    private void writeHtmlHeader(BufferedReader input, BufferedWriter output) throws IOException
    {
        String line;
        while( (line = input.readLine())!=null && !"${RESULT}".equals(line.trim()))
        {
            output.write(line);
            output.write('\n');
        }
    }

    /**
     * Write HTML footer which is read from a HTML template.
     * 
     * @param input
     * @param output
     * @throws IOException
     */
    private void writeHtmlFooter(BufferedReader input, BufferedWriter output) throws IOException
    {
        String line;
        while( (line = input.readLine())!=null)
        {
            output.write(line);
            output.write('\n');
        }
    }

    /**
     * Read all test results a and store them into a map.
     *
     * @return
     */
    private Map<String, TestResult> readAllTestResults()
    {
        Map<String, TestResult> results = new HashMap<String, TestResult>();
        File inputDir = this.configuration.getInputPath();

        if (inputDir == null || !inputDir.isDirectory())
        {
            return results;
        }
        for (String resultDir : inputDir.list())
        {
            File dir = new File(inputDir, resultDir);
            if (dir.isDirectory())
            {
                this.log.logBegin("processing directory " + resultDir);
                TestResult result = readTestResult(dir);
                results.put(resultDir, result);
                this.log.logEnd("processing directory " + resultDir);
            }
        }
        return results;
    }

    /**
     * Read and process test result from the file "results.xml".
     * 
     * @param resultDirectory
     *            directory containing test result(s)
     * 
     * @return results of one test run
     */
    @SuppressWarnings({ "boxing" })
    private TestResult readTestResult(File resultDirectory)
    {
        File resultFile = new File(resultDirectory, "results.xml");
        TestResult testResult = new TestResult();
        int totalTests = 0;
        int sameImages = 0;
        int differentImages = 0;
        try
        {
            DocumentBuilder builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
            Document document = builder.parse(resultFile);
            NodeList nodes = document.getElementsByTagName("test");
            // read all nodes under node "test"
            for (int i = 0; i < nodes.getLength(); i++)
            {
                Element testNode = (Element) nodes.item(i);
                this.log.logSet(testNode.getNodeName(), ""+i);

                Element patternNode = (Element) testNode.getElementsByTagName("pattern").item(0);
                String result = patternNode.getAttribute("result");
                this.log.logSet("result", result);
                totalTests ++;
                if ("same".equals(result))
                {
                    sameImages++;
                }
                else
                {
                    differentImages++;
                }
            }
        }
        catch (ParserConfigurationException e)
        {
            // print ST in case of exception
            e.printStackTrace();
        }
        catch (SAXException e)
        {
            // print ST in case of exception
            e.printStackTrace();
        }
        catch (IOException e)
        {
            // print ST in case of exception
            e.printStackTrace();
        }
        finally
        {
            testResult.setTotalTests(totalTests);
            testResult.setSameImages(sameImages);
            testResult.setDifferentImages(differentImages);
            this.log.logSet("total tests", totalTests);
            this.log.logSet("same images", sameImages);
            this.log.logSet("different images", differentImages);
        }
        return testResult;
    }

    /**
     * Entry to this application.
     *
     * @param args
     */
    public static void main(String[] args)
    {
        new Reporter().doReport(args);
    }

}
