/*
  Java gfx-test framework

   Copyright (C) 2013, 2014  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.geom.Area;



import org.gfxtest.framework.CommonCAGOperations;
import org.gfxtest.framework.CommonRenderingStyles;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test checks the process of creating and rendering new geometric shapes
 * by performing boolean operations on existing ones. This process is often
 * called Constructive area geometry (CAG). Various cases are checked by this
 * test suite.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.AREA)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class CAGOperationsOnPieAndRectangle extends GfxTest
{

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using union operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleUnionStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using intersect operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using subtract operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using inverse subtract operator.
     * The shape is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using Xor operator.
     * The shape is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleXorStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using union operator. The shape is
     * rendered using wide stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleUnionWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using intersect operator. The shape is
     * rendered using wide stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleIntersectWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using subtract operator. The shape
     * is rendered using wide stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleInverseSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using Xor operator.
     * The shape is rendered using wide stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleXorWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from pie and rectangle using union operator. The shape is
     * rendered using extra wide stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigPieRectangleUnionExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerPieAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new CAGOperationsOnPieAndRectangle().runTestSuite(args);
    }
}
