/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;



import java.awt.BasicStroke;
import java.awt.Graphics2D;



import org.gfxtest.callbacks.RectangleDrawCallbacks;
import org.gfxtest.framework.ColorPalette;
import org.gfxtest.framework.GrayscalePalette;
import org.gfxtest.framework.HSBPalette;
import org.gfxtest.framework.PrintTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test suite checks rendering of various rectangles.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.PRINT_TEST)
@GraphicsPrimitive(GraphicsPrimitives.RECTANGLE)
@RenderStyle(RenderStyles.NORMAL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class PrintTestRoundRectangles extends PrintTest
{

    /**
     * Method which renders set of rectangles using various colors and stroke
     * styles. For each rectangle, the callback function/method is called to
     * perform all required setup.
     * 
     * @param image
     *            image to which rectangles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param step
     *            between two near rectangles
     * @param rectangleDrawCallbacks
     *            class containing set of callback methods
     */
    private static void drawRoundRectangles(TestImage image, Graphics2D graphics, int step, RectangleDrawCallbacks rectangleDrawCallbacks)
    {
        // setup rendering
        rectangleDrawCallbacks.setup(image, graphics);

        // image width and height
        final int width = image.getWidth();
        final int height = image.getHeight();

        // horizontal coordinates of rectangle endpoints
        int x1 = BORDER;
        int x2 = width - BORDER;

        // vertical coordinates of rectangle endpoints
        int y1 = BORDER;
        int y2 = height - BORDER;

        // index to color palette
        int colorIndex = 0;

        // draw all rectangles onto a paper
        while (x1 < x2 - BORDER && y1 < y2 - BORDER)
        {
            // setup can be made for each rectangle
            rectangleDrawCallbacks.iterationCallBack(x1, y1, x2, y2, colorIndex++);
            // compute round rectangle parameters
            final int rectangleWidth = x2 - x1;
            final int rectangleHeight = y2 - y1;
            // compute rounding parameters
            final int arcWidth = rectangleWidth >> 1;
            final int arcHeight = rectangleHeight >> 1;
            final int arc = Math.max(arcWidth, arcHeight);
            // render the rectangle
            graphics.drawRoundRect(x1, y1, rectangleWidth, rectangleHeight, arc, arc);
            // setup coordinates for the next rectangle
            x1 += step;
            y1 += step;
            x2 -= step;
            y2 -= step;
        }

        // cleanup rendering
        rectangleDrawCallbacks.cleanup();
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect(). Round rectangles are
     * rendered with default width and default end caps. Color of all rendered
     * rectangles are set to black.
     * 
     * @param image
     *            image to which rectangles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesBasicStyle(TestImage image, Graphics2D graphics)
    {
        drawRoundRectangles(image, graphics, RECTANGLE_STEP, new RectangleDrawCallbacks()
        {
            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect(). Round rectangles are
     * rendered with default width and default end caps. Color of all rendered
     * rectangles are selected from a palette.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesColorPalette(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP, new RectangleDrawCallbacks()
        {
            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set new circle color to index
                this.graphics.setColor(ColorPalette.getColor(index));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect(). Round rectangles are
     * rendered with default width and default end caps. Color of all rendered
     * rectangles are selected from a palette.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesColorPaletteInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP, new RectangleDrawCallbacks()
        {
            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set new circle color according to index
                this.graphics.setColor(ColorPalette.getColor(MAX_COLOR_INDEX - index));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRect(). Rectangles are
     * rendered with default width and default end caps. Color of all rendered
     * rectangles are selected from a color palette.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesColorScale(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP, new RectangleDrawCallbacks()
        {
            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // compute hue value
                float hue = (x2 - x1) * 1.0f / (this.image.getWidth());
                // set circle color
                this.graphics.setColor(HSBPalette.createHsbColor(hue));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRect(). Rectangles are
     * rendered with default width and default end caps. Color of all rendered
     * rectangles are selected from a color palette.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesColorScaleInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP, new RectangleDrawCallbacks()
        {
            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // compute hue value
                float hue = 1.0f - (x2 - x1) * 1.0f / (this.image.getWidth());
                // set circle color
                this.graphics.setColor(HSBPalette.createHsbColor(hue));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect(). Round rectangles are
     * rendered with default width and default end caps. Color of all rendered
     * rectangles are selected from a grascale palette.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesGrayScale(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP, new RectangleDrawCallbacks()
        {
            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // compute grayscale value
                float gray = (x2 - x1) * 1.0f / (this.image.getWidth());
                // clamp the grayscale value
                if (gray > 1.0f)
                {
                    gray = 1.0f;
                }
                // set circle color
                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect(). Round rectangles are
     * rendered with default width and default end caps. Color of all rendered
     * rectangles are selected from a grascale palette.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesGrayScaleInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP, new RectangleDrawCallbacks()
        {
            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // compute grayscale value
                float gray = 1.0f - (x2 - x1) * 1.0f / (this.image.getWidth());
                // clamp the grayscale value
                if (gray < 0.0f)
                {
                    gray = 0.0f;
                }
                // set circle color
                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect(). Round rectangles are
     * rendered with various width and default end caps. Color of all rendered
     * rectangles are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidth(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapButtJoinBevel(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapButtJoinMiter(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapButtJoinRound(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapRoundJoinBevel(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapRoundJoinMiter(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapRoundJoinRound(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapSquareJoinBevel(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapSquareJoinMiter(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapSquareJoinRound(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MIN_STROKE_WIDTH;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth  = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect(). Round rectangles are
     * rendered with various width and default end caps. Color of all rendered
     * rectangles are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapButtJoinBevelInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapButtJoinMiterInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_BUTT.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapButtJoinRoundInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapRoundJoinBevelInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapRoundJoinMiterInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_ROUND.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapRoundJoinRoundInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to bevel style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapSquareJoinBevelInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to miter style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapSquareJoinMiterInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawRoundRect().
     * Round rectangles are rendered with various width and end caps set to CAP_SQUARE.
     * Join style is set to round style.
     * Color of all rendered lines are set to black.
     *
     * @param image
     *            image to which circles are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawRoundRectanglesChangeWidthCapSquareJoinRoundInv(TestImage image, Graphics2D graphics2d)
    {
        drawRoundRectangles(image, graphics2d, RECTANGLE_STEP * 3 / 2, new RectangleDrawCallbacks()
        {
            /**
             * Stroke width which is changed in each iteration.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each rectangle is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new PrintTestRoundRectangles().runTestSuite(args);
    }
}
